@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -163,10 +159,30 @@ public class FormatData_sr extends ListResourceBundle {
         final String[] metaValue_AmPmMarkers = new String[] {
                "\u043f\u0440\u0435 \u043f\u043e\u0434\u043d\u0435",
                "\u043f\u043e \u043f\u043e\u0434\u043d\u0435",
+               "\u043f\u043e\u043d\u043e\u045b",
+               "\u043f\u043e\u0434\u043d\u0435",
+               "\u0443\u0458\u0443\u0442\u0440\u043e",
+               "",
+               "\u043f\u043e \u043f\u043e\u0434\u043d\u0435",
+               "",
+               "\u0443\u0432\u0435\u0447\u0435",
+               "",
+               "\u043d\u043e\u045b\u0443",
+               "",
             };
         final String[] metaValue_narrow_AmPmMarkers = new String[] {
                "a",
                "p",
+               "\u043f\u043e\u043d\u043e\u045b",
+               "\u043f\u043e\u0434\u043d\u0435",
+               "\u0443\u0458\u0443\u0442\u0440\u0443",
+               "",
+               "\u043f\u043e \u043f\u043e\u0434\u043d\u0435",
+               "",
+               "\u0443\u0432\u0435\u0447\u0435",
+               "",
+               "\u043d\u043e\u045b\u0443",
+               "",
             };
         final String[] metaValue_TimePatterns = new String[] {
                "HH:mm:ss zzzz",
@@ -174,7 +190,7 @@ public class FormatData_sr extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
-        final String[] metaValue_buddhist_long_Eras = new String[] {
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "\u0411\u0415",
             };
@@ -190,11 +206,27 @@ public class FormatData_sr extends ListResourceBundle {
                "d.MM.y. GGGG",
                "d.M.y. G",
             };
-        final String[] metaValue_roc_long_Eras = new String[] {
+        final String[] metaValue_java_time_japanese_long_Eras = new String[] {
+               "\u043d\u043e\u0432\u0435 \u0435\u0440\u0435",
+               "\u041c\u0435\u0438\u0452\u0438",
+               "\u0422\u0430\u0438\u0448\u043e",
+               "\u0428\u043e\u0432\u0430",
+               "\u0425\u0430\u0438\u0441\u0435\u0438",
+               "\u0420\u0435\u0438\u0432\u0430",
+            };
+        final String[] metaValue_java_time_japanese_Eras = new String[] {
+               "\u043d. \u0435.",
+               "\u041c\u0435\u0438\u0452\u0438",
+               "\u0422\u0430\u0438\u0448\u043e",
+               "\u0428\u043e\u0432\u0430",
+               "\u0425\u0430\u0438\u0441\u0435\u0438",
+               "\u0420\u0435\u0438\u0432\u0430",
+            };
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "\u041f\u0440\u0435 \u0420\u041a",
                "\u0420\u041a",
             };
-        final String[] metaValue_islamic_long_Eras = new String[] {
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
                "\u0410\u0425",
             };
@@ -204,7 +236,7 @@ public class FormatData_sr extends ListResourceBundle {
             { "field.year", "\u0433\u043e\u0434\u0438\u043d\u0430" },
             { "calendarname.islamic-umalqura", "\u0438\u0441\u043b\u0430\u043c\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440 (Umm al-Qura)" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns",
                 new String[] {
@@ -220,7 +252,7 @@ public class FormatData_sr extends ListResourceBundle {
             { "calendarname.islamic-civil", "\u0418\u0441\u043b\u0430\u043c\u0441\u043a\u0438 \u0446\u0438\u0432\u0438\u043b\u043d\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
-            { "roc.long.Eras", metaValue_roc_long_Eras },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
                 new String[] {
                     "\u043f.\u043d.\u0435.",
@@ -234,6 +266,7 @@ public class FormatData_sr extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras",
                 new String[] {
                     "\u043f\u0440\u0435 \u043d\u043e\u0432\u0435 \u0435\u0440\u0435",
@@ -266,6 +299,8 @@ public class FormatData_sr extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
@@ -279,17 +314,8 @@ public class FormatData_sr extends ListResourceBundle {
             },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u043c\u0438\u043d\u0443\u0442" },
+            { "japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
             { "field.era", "\u0435\u0440\u0430" },
-            { "japanese.long.Eras",
-                new String[] {
-                    "\u043d\u043e\u0432\u0435 \u0435\u0440\u0435",
-                    "\u041c\u0435\u0438\u0452\u0438",
-                    "\u0422\u0430\u0438\u0448\u043e",
-                    "\u0428\u043e\u0432\u0430",
-                    "\u0425\u0430\u0438\u0441\u0435\u0438",
-                    "",
-                }
-            },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u043f\u0440\u0435 \u043f\u043e\u0434\u043d\u0435/\u043f\u043e \u043f\u043e\u0434\u043d\u0435" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
@@ -314,21 +340,18 @@ public class FormatData_sr extends ListResourceBundle {
             { "calendarname.roc", "\u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440 \u0420\u0435\u043f\u0443\u0431\u043b\u0438\u043a\u0435 \u041a\u0438\u043d\u0435" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_long_Eras },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "\u043c\u0435\u0441\u0435\u0446" },
-            { "roc.Eras", metaValue_roc_long_Eras },
+            { "java.time.japanese.long.Eras", metaValue_java_time_japanese_long_Eras },
+            { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0438\u0441\u043b\u0430\u043c\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "DayPeriodRules", "midnight:00:00;noon:12:00;night1:21:00-06:00;afternoon1:12:00-18:00;morning1:06:00-12:00;evening1:18:00-21:00" },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -337,18 +360,18 @@ public class FormatData_sr extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 \u0445\u0438\u0459\u0430\u0434\u0430",
-                    "00 \u0445\u0438\u0459\u0430\u0434\u0430",
-                    "000 \u0445\u0438\u0459\u0430\u0434\u0430",
-                    "0 \u043c\u0438\u043b\u0438\u043e\u043d",
-                    "00 \u043c\u0438\u043b\u0438\u043e\u043d",
-                    "000 \u043c\u0438\u043b\u0438\u043e\u043d",
-                    "0 \u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430",
-                    "00 \u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430",
-                    "000 \u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430",
-                    "0 \u0431\u0438\u043b\u0438\u043e\u043d",
-                    "00 \u0431\u0438\u043b\u0438\u043e\u043d",
-                    "000 \u0431\u0438\u043b\u0438\u043e\u043d",
+                    "{one:0' '\u0445\u0438\u0459\u0430\u0434\u0430 few:0' '\u0445\u0438\u0459\u0430\u0434\u0435 other:0' '\u0445\u0438\u0459\u0430\u0434\u0430}",
+                    "{one:00' '\u0445\u0438\u0459\u0430\u0434\u0430 few:00' '\u0445\u0438\u0459\u0430\u0434\u0435 other:00' '\u0445\u0438\u0459\u0430\u0434\u0430}",
+                    "{one:000' '\u0445\u0438\u0459\u0430\u0434\u0430 few:000' '\u0445\u0438\u0459\u0430\u0434\u0435 other:000' '\u0445\u0438\u0459\u0430\u0434\u0430}",
+                    "{one:0' '\u043c\u0438\u043b\u0438\u043e\u043d few:0' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430 other:0' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:00' '\u043c\u0438\u043b\u0438\u043e\u043d few:00' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430 other:00' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:000' '\u043c\u0438\u043b\u0438\u043e\u043d few:000' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430 other:000' '\u043c\u0438\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:0' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430 few:0' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0435 other:0' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0438}",
+                    "{one:00' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430 few:00' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0435 other:00' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0438}",
+                    "{one:000' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430 few:000' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0435 other:000' '\u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0438}",
+                    "{one:0' '\u0431\u0438\u043b\u0438\u043e\u043d few:0' '\u0431\u0438\u043b\u0438\u043e\u043d\u0430 other:0' '\u0431\u0438\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:00' '\u0431\u0438\u043b\u0438\u043e\u043d few:00' '\u0431\u0438\u043b\u0438\u043e\u043d\u0430 other:00' '\u0431\u0438\u043b\u0438\u043e\u043d\u0430}",
+                    "{one:000' '\u0431\u0438\u043b\u0438\u043e\u043d few:000' '\u0431\u0438\u043b\u0438\u043e\u043d\u0430 other:000' '\u0431\u0438\u043b\u0438\u043e\u043d\u0430}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -358,13 +381,15 @@ public class FormatData_sr extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.long.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "\u0432\u0440\u0435\u043c\u0435\u043d\u0441\u043a\u0430 \u0437\u043e\u043d\u0430" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.narrow.Eras", metaValue_roc_long_Eras },
+            { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras",
@@ -382,15 +407,18 @@ public class FormatData_sr extends ListResourceBundle {
             { "field.weekday", "\u0434\u0430\u043d \u0443 \u043d\u0435\u0434\u0435\u0459\u0438" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras", metaValue_islamic_long_Eras },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "java.time.japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "\u043d\u0435\u0434\u0435\u0459\u0430" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
@@ -404,21 +432,22 @@ public class FormatData_sr extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0\u0445\u0438\u0459'.'",
-                    "00\u00a0\u0445\u0438\u0459'.'",
-                    "000\u00a0\u0445\u0438\u0459'.'",
-                    "0\u00a0\u043c\u0438\u043b'.'",
-                    "00\u00a0\u043c\u0438\u043b'.'",
-                    "000\u00a0\u043c\u0438\u043b'.'",
-                    "0\u00a0\u043c\u043b\u0440\u0434'.'",
-                    "00\u00a0\u043c\u043b\u0440\u0434'.'",
-                    "000\u00a0\u043c\u043b\u0440\u0434'.'",
-                    "0\u00a0\u0431\u0438\u043b'.'",
-                    "00\u00a0\u0431\u0438\u043b'.'",
-                    "000\u00a0\u0431\u0438\u043b'.'",
+                    "{one:0\u00a0\u0445\u0438\u0459'.' few:0\u00a0\u0445\u0438\u0459'.' other:0\u00a0\u0445\u0438\u0459'.'}",
+                    "{one:00\u00a0\u0445\u0438\u0459'.' few:00\u00a0\u0445\u0438\u0459'.' other:00\u00a0\u0445\u0438\u0459'.'}",
+                    "{one:000\u00a0\u0445\u0438\u0459'.' few:000\u00a0\u0445\u0438\u0459'.' other:000\u00a0\u0445\u0438\u0459'.'}",
+                    "{one:0\u00a0\u043c\u0438\u043b'.' few:0\u00a0\u043c\u0438\u043b'.' other:0\u00a0\u043c\u0438\u043b'.'}",
+                    "{one:00\u00a0\u043c\u0438\u043b'.' few:00\u00a0\u043c\u0438\u043b'.' other:00\u00a0\u043c\u0438\u043b'.'}",
+                    "{one:000\u00a0\u043c\u0438\u043b'.' few:000\u00a0\u043c\u0438\u043b'.' other:000\u00a0\u043c\u0438\u043b'.'}",
+                    "{one:0\u00a0\u043c\u043b\u0440\u0434'.' few:0\u00a0\u043c\u043b\u0440\u0434'.' other:0\u00a0\u043c\u043b\u0440\u0434'.'}",
+                    "{one:00\u00a0\u043c\u043b\u0440\u0434'.' few:00\u00a0\u043c\u043b\u0440\u0434'.' other:00\u00a0\u043c\u043b\u0440\u0434'.'}",
+                    "{one:000\u00a0\u043c\u043b\u0440\u0434'.' few:000\u00a0\u043c\u043b\u0440\u0434'.' other:000\u00a0\u043c\u043b\u0440\u0434'.'}",
+                    "{one:0\u00a0\u0431\u0438\u043b'.' few:0\u00a0\u0431\u0438\u043b'.' other:0\u00a0\u0431\u0438\u043b'.'}",
+                    "{one:00\u00a0\u0431\u0438\u043b'.' few:00\u00a0\u0431\u0438\u043b'.' other:00\u00a0\u0431\u0438\u043b'.'}",
+                    "{one:000\u00a0\u0431\u0438\u043b'.' few:000\u00a0\u0431\u0438\u043b'.' other:000\u00a0\u0431\u0438\u043b'.'}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.regionFormat.daylight", "{0}, \u043b\u0435\u0442\u045a\u0435 \u0432\u0440\u0435\u043c\u0435" },
             { "DatePatterns",
                 new String[] {
@@ -432,25 +461,26 @@ public class FormatData_sr extends ListResourceBundle {
             { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
+            { "PluralRules", "one:v = 0 and i % 10 = 1 and i % 100 != 11 or f % 10 = 1 and f % 100 != 11;few:v = 0 and i % 10 = 2..4 and i % 100 != 12..14 or f % 10 = 2..4 and f % 100 != 12..14" },
             { "field.hour", "\u0441\u0430\u0442" },
-            { "islamic.narrow.Eras", metaValue_islamic_long_Eras },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "\u0431\u0443\u0434\u0438\u0441\u0442\u0438\u0447\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4;(#,##0.00\u00a0\u00a4)",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "japanese.Eras",
-                new String[] {
-                    "\u043d. \u0435.",
-                    "\u041c\u0435\u0438\u0452\u0438",
-                    "\u0422\u0430\u0438\u0448\u043e",
-                    "\u0428\u043e\u0432\u0430",
-                    "\u0425\u0430\u0438\u0441\u0435\u0438",
-                    "",
-                }
-            },
+            { "japanese.Eras", metaValue_java_time_japanese_Eras },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
